@@ -107,6 +107,26 @@ class Drive(NetBoxModel):
     def physicalvolumes_in_drive_count(self):
         return PhysicalVolume.objects.filter(drive=self).count()
 
+    def delete(self, *args, **kwargs):
+        if TemplateConfigurationDrive.objects.filter(drive=self).count() > 0:
+            tcd = TemplateConfigurationDrive.objects.get(drive=self)
+            print()
+            tcd_list = TemplateConfigurationDrive.objects.filter(platform=tcd.platform).exclude(drive=self)
+            super().delete(*args, **kwargs)
+            for idx, tcd in enumerate(tcd_list):
+                tcd.drive.identifier = f'Hard Drive {idx + 1}'
+        elif StorageConfigurationDrive.objects.filter(drive=self).count() > 0:
+            scd = StorageConfigurationDrive.objects.get(drive=self)
+            print(f"StorageConfigurationDriveObject: {scd}")
+            scd_list = StorageConfigurationDrive.objects.filter(virtual_machine=scd.virtual_machine).exclude(drive=self)
+            print(f"StorageConfigurationDrive List: {scd_list}")
+            super().delete(*args, **kwargs)
+            for idx, scd in enumerate(scd_list):
+                scd.drive.identifier = f'Hard Drive {idx + 1}'
+                print(f"New Identifier: {scd.drive.identifier}")
+                scd.save()
+
+
     def left_free_space(self):
         current_partition_allocated_space = Partition.objects.filter(drive=self).aggregate(sum=Sum('size')).get(
             'sum') or 0
