@@ -46,30 +46,15 @@ class PlatformTemplateContent(PluginTemplateExtension):
 
     def right_page(self):
         obj = self.context.get("object")
-
-        drives_id = TemplateConfigurationDrive.objects.values('drive').filter(platform=obj)
-        partition_dict = {}
-        for drive_id in drives_id:
-            print(f"Drive ID: {drive_id['drive']}")
-            drive = Drive.objects.get(pk=drive_id['drive'])
-
-            drive_type_id = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
-            linux_device_type_id = ContentType.objects.get(app_label='netbox_storage', model='linuxdevice').pk
-            # Get Linux Device of Drive e.g. /dev/sda
-            linux_device_drive = LinuxDevice.objects.get(content_type_id=drive_type_id,
-                                                         object_id=drive_id['drive'],
-                                                         type='Disk')
-
-            if LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
-                                          object_id=linux_device_drive.pk,
-                                          type='Partition').count() == 0:
-                partition_dict[drive] = None
-            else:
-                partition_dict[drive] = list(LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
-                                                                        object_id=linux_device_drive.pk,
-                                                                        type='Partition'))
-
         if obj.name.lower().__contains__('windows'):
+            drives_id = TemplateConfigurationDrive.objects.values('drive').filter(platform=obj)
+            partition_dict = {}
+            for drive_id in drives_id:
+                drive = Drive.objects.get(pk=drive_id['drive'])
+                if Partition.objects.filter(drive=drive).count() == 0:
+                    partition_dict[drive] = None
+                else:
+                    partition_dict[drive] = list(Partition.objects.filter(drive=drive))
             return self.render(
                 "netbox_storage/inc/template_windows_drive_box.html",
                 extra_context={
@@ -77,6 +62,27 @@ class PlatformTemplateContent(PluginTemplateExtension):
                 },
             )
         else:
+            drives_id = TemplateConfigurationDrive.objects.values('drive').filter(platform=obj)
+            partition_dict = {}
+            for drive_id in drives_id:
+                print(f"Drive ID: {drive_id['drive']}")
+                drive = Drive.objects.get(pk=drive_id['drive'])
+
+                drive_type_id = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
+                linux_device_type_id = ContentType.objects.get(app_label='netbox_storage', model='linuxdevice').pk
+                # Get Linux Device of Drive e.g. /dev/sda
+                linux_device_drive = LinuxDevice.objects.get(content_type_id=drive_type_id,
+                                                             object_id=drive_id['drive'],
+                                                             type='Disk')
+
+                if LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
+                                              object_id=linux_device_drive.pk,
+                                              type='Partition').count() == 0:
+                    partition_dict[drive] = None
+                else:
+                    partition_dict[drive] = list(LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
+                                                                            object_id=linux_device_drive.pk,
+                                                                            type='Partition'))
             return self.render(
                 "netbox_storage/inc/template_drive_box.html",
                 extra_context={
